==> pan-0.90.tar.bz2: pan-0.90/pan/gui/header-pane.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002-2006  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _HeaderPane_h_
#define _HeaderPane_h_

#include <gtk/gtk.h>
#include <pan/data/article-cache.h>
#include <pan/data/data.h>
#include <pan/data/filter-info.h>
#include <pan/gui/action-manager.h>

namespace pan
{
  /**
   * Base class for functors taking a const Article& and returning bool.
   * @ingroup GUI
   */
  struct ArticleFunctor
  {
    virtual ~ArticleFunctor() {}
    virtual bool operator()(const Article&) const = 0;
  };

  /**
   * Header Pane in the main window of Pan's GUI.
   * @ingroup GUI
   */
  class HeaderPane:
    private Data::Listener,
    private Data::ArticleTree::Listener
  {
    public:
      HeaderPane (ActionManager&, Data& data, const ArticleCache&);
      ~HeaderPane ();

    public:
      void refilter ();

    public:
      void unselect_all ();
      void select_all ();
      void select_threads ();
      void select_subthreads ();

    public:
      void read_next_article ();
      void read_next_unread_article ();
      void read_next_thread ();
      void read_next_unread_thread ();
      void read_previous_article ();
      void read_previous_thread ();
      void read_parent_article ();

    private:
      void read_next_if (const ArticleFunctor&);
      void read_prev_if (const ArticleFunctor&);

    public:
      GtkWidget* root () { return _root; }
      const Article* get_first_selected_article () const;
      std::set<const Article*> get_full_selection () const;
      bool set_group (const Quark& group);
      void clear_group ();
      const Quark& get_group () { return _group; }

    private:
      friend class Data; // so it fires to our private listener
      virtual void on_group_read (const Quark& group);

    private:
      friend class Data::ArticleTree; // so it fires to our private listener
      virtual void on_tree_change (const Data::ArticleTree::Diffs&);

    public: // pretend it's private
      ActionManager& _action_manager;

    private:
      Data& _data;
      Quark _group;
      Data::ArticleTree * _atree;
      GtkWidget * _root;
      GtkWidget * _entry;
      GtkWidget * _tree_view;
      GtkWidget * _toolbar_bin;
      GtkTreeStore * _tree_store;
      FilterInfo _filter;

    public: // pretend this is private!

      /**
       * Private implementation class for Header Pane.
       *
       * It's used to map GtkTreeIters to Articles
       * and utf-8 friendly collation strings for the
       * author and subject.
       *
       * Treat this as a header-pane private class.
       * It's only visible because static functions
       * in header-pane.cc need access to it.
       */       
      class ArticleViewRec {
        private:
          char * collated_subject;
          char * collated_author;
        public:
          const Article * article;
          const char * get_subject ();
          const char * get_author ();
          StringView short_author;
        public:
          ArticleViewRec (): collated_subject(0), collated_author(0), article(0) {}
          ~ArticleViewRec ();
          void set_article (const Article* a);
      };
      typedef std::map<void*,ArticleViewRec> iter_to_view_record_t;
      iter_to_view_record_t _iter_to_view_record;

    private:
      void rebuild_filter (const std::string&, int);

    public: // public so that anonymous namespace can reach -- don't call
      void filter (const std::string& text, int mode);
      static void do_popup_menu (GtkWidget*, GdkEventButton*, gpointer);
      static void on_row_activated (GtkTreeView*, GtkTreePath*, GtkTreeViewColumn*, gpointer);
      const ArticleCache& _cache;
  };
}

#endif

==> pan-0.92.tar.bz2: pan-0.92/pan/gui/header-pane.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002-2006  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _HeaderPane_h_
#define _HeaderPane_h_

#include <gtk/gtk.h>
#include <pan/data/article-cache.h>
#include <pan/data/data.h>
#include <pan/data/filter-info.h>
#include <pan/gui/action-manager.h>
#include <pan/gui/ui-prefs.h>

namespace pan
{
  /**
   * Base class for functors taking a const Article& and returning bool.
   * @ingroup GUI
   */
  struct ArticleFunctor
  {
    virtual ~ArticleFunctor() {}
    virtual bool operator()(const Article&) const = 0;
  };

  /**
   * Header Pane in the main window of Pan's GUI.
   * @ingroup GUI
   */
  class HeaderPane:
    private Data::Listener,
    private Data::ArticleTree::Listener
  {
    public:
      HeaderPane (ActionManager&, Data& data, const ArticleCache&, const UI_Prefs&);
      ~HeaderPane ();

    public:
      void refilter ();

    public:
      void unselect_all ();
      void select_all ();
      void select_threads ();
      void select_subthreads ();

    public:
      void read_next_article ();
      void read_next_unread_article ();
      void read_next_thread ();
      void read_next_unread_thread ();
      void read_previous_article ();
      void read_previous_thread ();
      void read_parent_article ();

    private:
      void read_next_if (const ArticleFunctor&);
      void read_prev_if (const ArticleFunctor&);

    public:
      GtkWidget* root () { return _root; }
      const Article* get_first_selected_article () const;
      std::set<const Article*> get_full_selection () const;
      bool set_group (const Quark& group);
      void clear_group ();
      const Quark& get_group () { return _group; }

    private:
      friend class Data; // so it fires to our private listener
      virtual void on_group_read (const Quark& group);

    private:
      friend class Data::ArticleTree; // so it fires to our private listener
      virtual void on_tree_change (const Data::ArticleTree::Diffs&);

    public: // pretend it's private
      ActionManager& _action_manager;

    private:
      Data& _data;
      const UI_Prefs& _prefs;
      Quark _group;
      Data::ArticleTree * _atree;
      GtkWidget * _root;
      GtkWidget * _entry;
      GtkWidget * _tree_view;
      GtkWidget * _toolbar_bin;
      GtkTreeStore * _tree_store;
      FilterInfo _filter;

    public: // pretend this is private!

      /**
       * Private implementation class for Header Pane.
       *
       * It's used to map GtkTreeIters to Articles
       * and utf-8 friendly collation strings for the
       * author and subject.
       *
       * Treat this as a header-pane private class.
       * It's only visible because static functions
       * in header-pane.cc need access to it.
       */       
      class ArticleViewRec {
        private:
          char * collated_subject;
          char * collated_author;
        public:
          const Article * article;
          const char * get_subject ();
          const char * get_author ();
          StringView short_author;
        public:
          ArticleViewRec (): collated_subject(0), collated_author(0), article(0) {}
          ~ArticleViewRec ();
          void set_article (const Article* a);
      };
      typedef std::map<void*,ArticleViewRec> iter_to_view_record_t;
      iter_to_view_record_t _iter_to_view_record;

    private:
      void rebuild_filter (const std::string&, int);

    public: // public so that anonymous namespace can reach -- don't call
      void filter (const std::string& text, int mode);
      static void do_popup_menu (GtkWidget*, GdkEventButton*, gpointer);
      static void on_row_activated (GtkTreeView*, GtkTreePath*, GtkTreeViewColumn*, gpointer);
      static gboolean on_button_pressed (GtkWidget*, GdkEventButton*, gpointer);
      const ArticleCache& _cache;
  };
}

#endif
